<?php

namespace wcf\system\event\listener;

use wcf\system\cache\builder\MyElistingCacheBuilder;

use wcf\util\HTTPRequest;
use wcf\util\JSON;
use wcf\data\user\User;
use wcf\system\WCF;

class MyelistingProfileStats implements IParameterizedEventListener
{

    public function execute($eventObj, $className, $eventName, array &$parameters)
    {
        $userID = $eventObj->userID;
        $user = new User($userID);
        $ebayName = $user->getUserOption('myelisting_ebay_username');

        if ($ebayName === null) {
            WCF::getTPL()->assign("myelistingNumberArticles", '-');
            return;
        }

        $cache = MyElistingCacheBuilder::getInstance();

        try {
            $numberArticles = $cache->getData(array(), 'numberArticles');
            if(isset($numberArticles[$ebayName])) {
                $numberArticles = $numberArticles[$ebayName];
            } else {
                $numberArticles = null;
            }
        } catch(\Exception $e) {
            $numberArticles = null;
        }


        // If my.eListing API not available set number articles to 'Error' and cache for only 5 min
        if ($numberArticles === false) {
            $data = $cache->rebuild(array('function' => 'numberArticles', 'value' => $ebayName));
            $numberArticles = $data['numberArticles'][$ebayName];
        }


        WCF::getTPL()->assign(array(
            "myelistingNumberArticles" => $numberArticles,
            "myelistingEbayName" => $ebayName,
        ));


    }
}